pub struct InputTypes(/* private fields */);Expand description
Identifies the types of input events which may be handled by a View.
Implementations
Sourceimpl InputTypes
impl InputTypes
Sourcepub const KEY: InputTypes
pub const KEY: InputTypes
Keyboard events.
Sourcepub const MOUSE_CLICK: InputTypes
pub const MOUSE_CLICK: InputTypes
Mouse button events, for any button.
Sourcepub const MOUSE_WHEEL: InputTypes
pub const MOUSE_WHEEL: InputTypes
Mouse scroll wheel events.
Sourcepub const MOUSE_MOVE: InputTypes
pub const MOUSE_MOVE: InputTypes
Mouse movement events.
Sourcepub const GESTURE_TAP: InputTypes
pub const GESTURE_TAP: InputTypes
Single tapping with one finger.
Sourcepub const GESTURE_PINCH: InputTypes
pub const GESTURE_PINCH: InputTypes
Pinching (for zooming).
Sourcepub const GESTURE_DRAG: InputTypes
pub const GESTURE_DRAG: InputTypes
Dragging a finger (for scrolling).
Sourcepub const ALL: InputTypes
pub const ALL: InputTypes
Matches all input types.
Sourceimpl InputTypes
impl InputTypes
Sourcepub const fn empty() -> InputTypes
pub const fn empty() -> InputTypes
Get a flags value with all bits unset.
Sourcepub const fn all() -> InputTypes
pub const fn all() -> InputTypes
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<InputTypes>
pub const fn from_bits(bits: u64) -> Option<InputTypes>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> InputTypes
pub const fn from_bits_truncate(bits: u64) -> InputTypes
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> InputTypes
pub const fn from_bits_retain(bits: u64) -> InputTypes
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<InputTypes>
pub fn from_name(name: &str) -> Option<InputTypes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: InputTypes) -> bool
pub const fn intersects(&self, other: InputTypes) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: InputTypes) -> bool
pub const fn contains(&self, other: InputTypes) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: InputTypes)
pub fn insert(&mut self, other: InputTypes)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: InputTypes)
pub fn remove(&mut self, other: InputTypes)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: InputTypes)
pub fn toggle(&mut self, other: InputTypes)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: InputTypes, value: bool)
pub fn set(&mut self, other: InputTypes, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: InputTypes) -> InputTypes
pub const fn intersection(self, other: InputTypes) -> InputTypes
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: InputTypes) -> InputTypes
pub const fn union(self, other: InputTypes) -> InputTypes
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: InputTypes) -> InputTypes
pub const fn difference(self, other: InputTypes) -> InputTypes
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: InputTypes) -> InputTypes
pub const fn symmetric_difference(self, other: InputTypes) -> InputTypes
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> InputTypes
pub const fn complement(self) -> InputTypes
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl InputTypes
impl InputTypes
Sourcepub const fn iter(&self) -> Iter<InputTypes> ⓘ
pub const fn iter(&self) -> Iter<InputTypes> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InputTypes> ⓘ
pub const fn iter_names(&self) -> IterNames<InputTypes> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.