RequestedNavigation

Struct RequestedNavigation 

pub struct RequestedNavigation {
    pub id: Option<u64>,
    pub phase: Option<NavigationPhase>,
    pub is_main_frame: Option<bool>,
    pub is_same_document: Option<bool>,
    pub is_http_post: Option<bool>,
    pub url: Option<String>,
    pub has_gesture: Option<bool>,
    pub was_server_redirect: Option<bool>,
    /* private fields */
}

Fields

id: Option<u64>

Unique ID of the navigation.

phase: Option<NavigationPhase>

Current navigation phase. Exactly one bit will be set.

is_main_frame: Option<bool>

Whether the navigation is taking place in the main frame versus in a subframe.

is_same_document: Option<bool>

Whether the navigation happened without changing the document.

is_http_post: Option<bool>

Whether the navigation is a POST request.

url: Option<String>

The current target URL of the navigation. This may change for the same navigation after encountering a server redirect.

has_gesture: Option<bool>

Whether the navigation was initiated by a user gesture.

was_server_redirect: Option<bool>

Whether the navigation has encountered a server redirect or not.